@@ -117,9 +117,9 @@ def _get_arg_parser():
     dp.add_argument("--all", help="Destroy all hosts spawned in the clouds", action='store_true')
     dp.add_argument("name", help="Name fo the group of hosts to destroy", nargs='?')
 
-    sp = subp.add_parser("deploy", help="Deploy masterfiles to hub")
+    sp = subp.add_parser("deploy", help="Deploy policy-set (masterfiles) to hub")
     sp.add_argument("--hub", help="Hub(s) to deploy to", type=str)
-    sp.add_argument("masterfiles", help="Path to local masterfiles directory or tarball", type=str, nargs="?")
+    sp.add_argument("masterfiles", help="Policy-set location (tarball URL or local path to tarball / directory)", type=str, nargs="?")
 
     return ap
 
